@@ -1,10 +1,11 @@
 from icalendar.cal import Calendar, Event, Todo, Journal
-from icalendar.cal import FreeBusy, Timezone, Alarm, ComponentFactory
+from icalendar.cal import Timezone, TimezoneStandard, TimezoneDaylight
+from icalendar.cal import FreeBusy, Alarm, ComponentFactory
 
 # Property Data Value Types
-from icalendar.prop import vBinary, vBoolean, vCalAddress, vDatetime, vDate, \
-     vDDDTypes, vDuration, vFloat, vInt, vPeriod, \
-     vWeekday, vFrequency, vRecur, vText, vTime, vUri, \
+from icalendar.prop import vBinary, vBoolean, vCalAddress, vDatetime, vDate,\
+     vDDDTypes, vDuration, vFloat, vInt, vPeriod,\
+     vWeekday, vFrequency, vRecur, vText, vTime, vUri,\
      vGeo, vUTCOffset, TypesFactory
 
 # useful tzinfo subclasses
@@ -16,7 +17,8 @@ from icalendar.parser import Parameters, q_split, q_join
 
 __all__ = [
     Calendar, Event, Todo, Journal,
-    FreeBusy, Timezone, Alarm, ComponentFactory,
+    FreeBusy, Alarm, ComponentFactory,
+    Timezone, TimezoneStandard, TimezoneDaylight,
     vBinary, vBoolean, vCalAddress, vDatetime, vDate,
     vDDDTypes, vDuration, vFloat, vInt, vPeriod,
     vWeekday, vFrequency, vRecur, vText, vTime, vUri,
