@@ -52,6 +52,8 @@ class ComponentFactory(CaselessDict):
         self['VJOURNAL'] = Journal
         self['VFREEBUSY'] = FreeBusy
         self['VTIMEZONE'] = Timezone
+        self['STANDARD'] = TimezoneStandard
+        self['DAYLIGHT'] = TimezoneDaylight
         self['VALARM'] = Alarm
         self['VCALENDAR'] = Calendar
 
@@ -233,16 +235,19 @@ class Component(CaselessDict):
         """Conditional convertion of values.
 
         """
-        if cond:
-            klass = types_factory.for_property(name)
-            _klass = klass(value)
-            if hasattr(value, 'params') and len(value.params.keys()) > 0:
-                _klass.params = value.params
-            return _klass
-        return value
+        if not cond: return value
+        klass = types_factory.for_property(name)
+        obj = klass(value)
+        if hasattr(value, 'params') and len(value.params.keys()) > 0:
+            # TODO: How can a python native value have params?
+            obj.params = value.params
+        return obj
 
     def set(self, name, value, encode=1):
-        if type(value) == ListType:
+        if encode and type(value) == ListType\
+                and name.lower() not in ['rdate', 'exdate']:
+            # Individually convert each value to an ical type except rdate and
+            # exdate, where lists of dates might be passed to vDDDLists.
             self[name] = [self._encode(name, v, encode) for v in value]
         else:
             self[name] = self._encode(name, value, encode)
@@ -281,7 +286,7 @@ class Component(CaselessDict):
                 # assume UTC for naive datetime instances
                 value = pytz.utc.localize(value)
 
-        # If property exists append, else create and set it.
+        # If property already exists, append it. Otherwise create and set it.
         if name in self:
             oldval = self[name]
             value = self._encode(name, value, encode)
@@ -291,10 +296,6 @@ class Component(CaselessDict):
                 self.set(name, [oldval, value], encode=0)
         else:
             self.set(name, value, encode)
-        if getattr(value, 'tzinfo', False) and value.tzinfo is not None and value.tzinfo is not pytz.utc:
-            # set the timezone as a parameter to the property
-            tzid = value.tzinfo.zone
-            self[name].params.update({'TZID': tzid})
 
     def _decode(self, name, value):
         # internal for decoding property values
@@ -389,11 +390,13 @@ class Component(CaselessDict):
         properties.append(('END', vText(self.name).to_ical()))
         return properties
 
+    @staticmethod
     def from_ical(st, multiple=False):
         """
         Populates the component recursively from a string
 
-        RecurrenceIDs may contain a TZID parameter, if so, they should create a tz localized datetime, otherwise, create a naive datetime
+        RecurrenceIDs may contain a TZID parameter, if so, they should create
+        a tz localized datetime, otherwise, create a naive datetime
         >>> componentStr = 'BEGIN:VEVENT\\nRECURRENCE-ID;TZID=America/Denver:20120404T073000\\nEND:VEVENT'
         >>> component = Component.from_ical(componentStr)
         >>> component['RECURRENCE-ID'].dt.tzinfo
@@ -415,11 +418,11 @@ class Component(CaselessDict):
             if uname == 'BEGIN':
                 # try and create one of the components defined in the spec,
                 # otherwise get a general Components for robustness.
-                component_name = vals.upper()
-                component_class = component_factory.get(component_name, Component)
-                component = component_class()
-                if not getattr(component, 'name', ''): # for undefined components
-                    component.name = component_name
+                c_name = vals.upper()
+                c_class = component_factory.get(c_name, Component)
+                component = c_class()
+                if not getattr(component, 'name', ''): # undefined components
+                    component.name = c_name
                 stack.append(component)
             # check for end of event
             elif uname == 'END':
@@ -436,7 +439,8 @@ class Component(CaselessDict):
                 factory = types_factory.for_property(name)
                 component = stack[-1]
                 try:
-                    if name in ('DTSTART', 'DTEND','RECURRENCE-ID') and 'TZID' in params: # TODO: add DUE, FREEBUSY
+                    if name in ('DTSTART', 'DTEND', 'RECURRENCE-ID')\
+                            and 'TZID' in params: # TODO: add DUE, FREEBUSY, RDATE, EXDATE ..
                         vals = factory(factory.from_ical(vals, params['TZID']))
                     else:
                         vals = factory(factory.from_ical(vals))
@@ -455,9 +459,9 @@ class Component(CaselessDict):
                              'only one is allowed: {st!r}'.format(**locals()))
         if len(comps) < 1:
             raise ValueError('Found no components where '
-                             'exactly one is required: {st!r}'.format(**locals()))
+                             'exactly one is required: '
+                             '{st!r}'.format(**locals()))
         return comps[0]
-    from_ical = staticmethod(from_ical)
 
     def __repr__(self):
         return '%s(' % self.name + dict.__repr__(self) + ')'
@@ -496,9 +500,9 @@ class Event(Component):
 
     required = ('UID',)
     singletons = (
-        'CLASS', 'CREATED', 'DESCRIPTION', 'DTSTART', 'GEO',
-        'LAST-MODIFIED', 'LOCATION', 'ORGANIZER', 'PRIORITY', 'DTSTAMP', 'SEQUENCE',
-        'STATUS', 'SUMMARY', 'TRANSP', 'URL', 'RECURRENCE-ID', 'DTEND', 'DURATION',
+        'CLASS', 'CREATED', 'DESCRIPTION', 'DTSTART', 'GEO', 'LAST-MODIFIED',
+        'LOCATION', 'ORGANIZER', 'PRIORITY', 'DTSTAMP', 'SEQUENCE', 'STATUS',
+        'SUMMARY', 'TRANSP', 'URL', 'RECURRENCE-ID', 'DTEND', 'DURATION',
         'DTSTART',
     )
     exclusive = ('DTEND', 'DURATION', )
@@ -517,7 +521,8 @@ class Todo(Component):
     singletons = (
         'CLASS', 'COMPLETED', 'CREATED', 'DESCRIPTION', 'DTSTAMP', 'DTSTART',
         'GEO', 'LAST-MODIFIED', 'LOCATION', 'ORGANIZER', 'PERCENT', 'PRIORITY',
-        'RECURRENCE-ID', 'SEQUENCE', 'STATUS', 'SUMMARY', 'UID', 'URL', 'DUE', 'DURATION',
+        'RECURRENCE-ID', 'SEQUENCE', 'STATUS', 'SUMMARY', 'UID', 'URL', 'DUE',
+        'DURATION',
     )
     exclusive = ('DUE', 'DURATION',)
     multiple = (
@@ -532,8 +537,9 @@ class Journal(Component):
 
     required = ('UID',)
     singletons = (
-        'CLASS', 'CREATED', 'DESCRIPTION', 'DTSTART', 'DTSTAMP', 'LAST-MODIFIED',
-        'ORGANIZER', 'RECURRENCE-ID', 'SEQUENCE', 'STATUS', 'SUMMARY', 'UID', 'URL',
+        'CLASS', 'CREATED', 'DESCRIPTION', 'DTSTART', 'DTSTAMP',
+        'LAST-MODIFIED', 'ORGANIZER', 'RECURRENCE-ID', 'SEQUENCE', 'STATUS',
+        'SUMMARY', 'UID', 'URL',
     )
     multiple = (
         'ATTACH', 'ATTENDEE', 'CATEGORIES', 'COMMENT', 'CONTACT', 'EXDATE',
@@ -554,16 +560,24 @@ class FreeBusy(Component):
 
 
 class Timezone(Component):
-
     name = 'VTIMEZONE'
-    canonical_order = ('TZID', 'STANDARDC', 'DAYLIGHTC',)
+    canonical_order = ('TZID', 'STANDARD', 'DAYLIGHT',)
+    required = ('TZID', 'STANDARD', 'DAYLIGHT',)
+    singletons = ('TZID', 'LAST-MODIFIED', 'TZURL',)
 
-    required = (
-        'TZID', 'STANDARDC', 'DAYLIGHTC', 'DTSTART', 'TZOFFSETTO',
-        'TZOFFSETFROM'
-        )
-    singletons = ('LAST-MODIFIED', 'TZURL', 'TZID',)
-    multiple = ('COMMENT', 'RDATE', 'RRULE', 'TZNAME',)
+
+class TimezoneStandard(Component):
+    name = 'STANDARD'
+    required = ('DTSTART', 'TZOFFSETTO', 'TZOFFSETFROM')
+    singletons = ('DTSTART', 'TZOFFSETTO', 'TZOFFSETFROM', 'RRULE')
+    multiple = ('COMMENT', 'RDATE', 'TZNAME')
+
+
+class TimezoneDaylight(Component):
+    name = 'DAYLIGHT'
+    required = ('DTSTART', 'TZOFFSETTO', 'TZOFFSETFROM')
+    singletons = ('DTSTART', 'TZOFFSETTO', 'TZOFFSETFROM', 'RRULE')
+    multiple = ('COMMENT', 'RDATE', 'TZNAME')
 
 
 class Alarm(Component):
@@ -573,7 +587,6 @@ class Alarm(Component):
     required = ('ACTION', 'TRIGGER',)
     singletons = ('ATTACH', 'ACTION', 'TRIGGER', 'DURATION', 'REPEAT',)
     inclusive = (('DURATION', 'REPEAT',),)
-    multiple = ('STANDARDC', 'DAYLIGHTC')
 
 
 class Calendar(Component):
