@@ -4,7 +4,8 @@
 def canonsort_keys(keys, canonical_order=None):
     """
     Sorts leading keys according to canonical_order.
-    Keys not specified in canonical_order will appear alphabetically at the end.
+    Keys not specified in canonical_order will appear alphabetically at the
+    end.
 
     >>> from icalendar.caselessdict import canonsort_keys
     >>> keys = ['DTEND', 'DTSTAMP', 'DTSTART', 'UID', 'SUMMARY', 'LOCATION']
@@ -20,7 +21,8 @@ def canonsort_keys(keys, canonical_order=None):
     canonical_map = dict((k, i) for i, k in enumerate(canonical_order or []))
     head = [k for k in keys if k in canonical_map]
     tail = [k for k in keys if k not in canonical_map]
-    return sorted(head, key=lambda k: canonical_map[k])  +  sorted(tail)
+    return sorted(head, key=lambda k: canonical_map[k]) + sorted(tail)
+
 
 def canonsort_items(dict1, canonical_order=None):
     """
@@ -35,6 +37,7 @@ def canonsort_items(dict1, canonical_order=None):
     """
     return [(k, dict1[k]) for k in canonsort_keys(dict1.keys(), canonical_order)]
 
+
 class CaselessDict(dict):
     """
     A dictionary that isn't case sensitive, and only uses strings as keys.
@@ -80,7 +83,7 @@ class CaselessDict(dict):
     def __init__(self, *args, **kwargs):
         "Set keys to upper for initial dict"
         dict.__init__(self, *args, **kwargs)
-        for k,v in self.items():
+        for k, v in self.items():
             k_upper = k.upper()
             if k != k_upper:
                 dict.__delitem__(self, k)
@@ -95,8 +98,8 @@ class CaselessDict(dict):
     def __delitem__(self, key):
         dict.__delitem__(self, key.upper())
 
-    def __contains__(self, item):
-        return dict.__contains__(self, item.upper())
+    def __contains__(self, key):
+        return dict.__contains__(self, key.upper())
 
     def get(self, key, default=None):
         return dict.get(self, key.upper(), default)
