@@ -37,7 +37,6 @@ them directly.
 
 """
 
-import pytz
 import re
 import time as _time
 import binascii
@@ -49,6 +48,9 @@ from datetime import (
     tzinfo,
 )
 from types import TupleType, ListType
+
+import pytz
+from dateutil.tz import tzutc
 from icalendar.caselessdict import CaselessDict
 from icalendar.parser import Parameters
 from icalendar.parser import escape_char
@@ -109,6 +111,7 @@ class vBinary:
     def to_ical(self):
         return binascii.b2a_base64(self.obj)[:-1]
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -116,8 +119,6 @@ class vBinary:
         except UnicodeError:
             raise ValueError, 'Not valid base 64 encoding.'
 
-    from_ical = staticmethod(from_ical)
-
 
 class vBoolean(int):
     """Returns specific string according to state.
@@ -149,6 +150,7 @@ class vBoolean(int):
 
     bool_map = CaselessDict(true=True, false=False)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -156,8 +158,6 @@ class vBoolean(int):
         except:
             raise ValueError, "Expected 'TRUE' or 'FALSE'. Got %s" % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vCalAddress(str):
     """This just returns an unquoted string.
@@ -185,6 +185,7 @@ class vCalAddress(str):
     def to_ical(self):
         return str(self)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -192,8 +193,6 @@ class vCalAddress(str):
         except:
             raise ValueError, 'Expected vCalAddress, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 ####################################################
 # handy tzinfo classes you can use.
@@ -275,6 +274,7 @@ class vFloat(float):
     def to_ical(self):
         return str(self)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -282,8 +282,6 @@ class vFloat(float):
         except:
             raise ValueError, 'Expected float value, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vInt(int):
     """Just an int.
@@ -307,6 +305,7 @@ class vInt(int):
     def to_ical(self):
         return str(self)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -314,8 +313,6 @@ class vInt(int):
         except:
             raise ValueError, 'Expected int, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vDDDLists:
     """A list of vDDDTypes values.
@@ -343,11 +340,6 @@ class vDDDLists:
     >>> str(dt_list[2])
     '1996-04-04 01:00:00+00:00'
 
-    >>> dt_list = vDDDLists('19960402T010000Z')
-    Traceback (most recent call last):
-        ...
-    ValueError: Value MUST be a list (of date instances)
-
     >>> dt_list = vDDDLists([])
     >>> dt_list.to_ical()
     ''
@@ -359,14 +351,23 @@ class vDDDLists:
     >>> dt_list = vDDDLists([datetime(2000,1,1), datetime(2000,11,11)])
     >>> dt_list.to_ical()
     '20000101T000000,20001111T000000'
+
     """
 
     def __init__(self, dt_list):
-        if not isinstance(dt_list, list):
-            raise ValueError('Value MUST be a list (of date instances)')
+        if not hasattr(dt_list, '__iter__'):
+            dt_list = [dt_list]
         vDDD = []
+        tzid = None
         for dt in dt_list:
-            vDDD.append(vDDDTypes(dt))
+            dt = vDDDTypes(dt)
+            vDDD.append(dt)
+            if 'TZID' in dt.params:
+                tzid = dt.params['TZID']
+
+        if tzid:
+            self.params = Parameters({'TZID': tzid}) # NOTE: no support for
+                                                     # multiple timezones here!
         self.dts = vDDD
 
     def to_ical(self):
@@ -375,18 +376,17 @@ class vDDDLists:
         dts_ical = [dt.to_ical() for dt in self.dts]
         return ",".join(dts_ical)
 
-    def from_ical(ical):
+    @staticmethod
+    def from_ical(ical, timezone=None):
         '''Parses the list of data formats from ical text format.
         @param ical: ical text format
         '''
         out = []
         ical_dates = ical.split(",")
         for ical_dt in ical_dates:
-            out.append(vDDDTypes.from_ical(ical_dt))
+            out.append(vDDDTypes.from_ical(ical_dt, timezone=timezone))
         return out
 
-    from_ical = staticmethod(from_ical)
-
 
 class vDDDTypes:
     """A combined Datetime, Date or Duration parser/generator. Their format
@@ -427,6 +427,14 @@ class vDDDTypes:
             self.params = Parameters(dict(value='DATE'))
         elif isinstance(dt, time):
             self.params = Parameters(dict(value='TIME'))
+
+        if (isinstance(dt, datetime) or isinstance(dt, time))\
+            and getattr(dt, 'tzinfo', False):
+            tzinfo = dt.tzinfo
+            if tzinfo is not pytz.utc and not isinstance(tzinfo, tzutc):
+                # set the timezone as a parameter to the property
+                tzid = dt.tzinfo.zone
+                self.params.update({'TZID': tzid})
         self.dt = dt
 
     def to_ical(self):
@@ -442,6 +450,7 @@ class vDDDTypes:
         else:
             raise ValueError('Unknown date type')
 
+    @staticmethod
     def from_ical(ical, timezone=None):
         "Parses the data format from ical text format"
         if isinstance(ical, vDDDTypes):
@@ -457,8 +466,6 @@ class vDDDTypes:
             except ValueError:
                 return vTime.from_ical(ical)
 
-    from_ical = staticmethod(from_ical)
-
 
 class vDate:
     """Render and generates iCalendar date format.
@@ -489,6 +496,7 @@ class vDate:
     def to_ical(self):
         return "%04d%02d%02d" % (self.dt.year, self.dt.month, self.dt.day)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -501,15 +509,13 @@ class vDate:
         except:
             raise ValueError, 'Wrong date format %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vDatetime:
     """Render and generates icalendar datetime format.
 
     vDatetime is timezone aware and uses the pytz library, an implementation of
     the Olson database in Python. When a vDatetime object is created from an
-    ical string, the string must be a valid pytz timezone identifier. When and
+    ical string, you can pass a valid pytz timezone identifier. When a
     vDatetime object is created from a python datetime object, it uses the
     tzinfo component, if present. Otherwise an timezone-naive object is
     created. Be aware that there are certain limitations with timezone naive
@@ -581,6 +587,7 @@ class vDatetime:
             self.params.update({'TZID': tzid})
         return s
 
+    @staticmethod
     def from_ical(ical, timezone=None):
         """ Parses the data format from ical text format.
 
@@ -612,8 +619,6 @@ class vDatetime:
         except:
             raise ValueError, 'Wrong datetime format: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vDuration:
     """Subclass of timedelta that renders itself in the iCalendar DURATION
@@ -693,6 +698,7 @@ class vDuration:
         else:
             return "%sP%dD%s" % (sign, abs(self.td.days), timepart)
 
+    @staticmethod
     def from_ical(ical):
         """ Parses the data format from ical text format.
 
@@ -713,8 +719,6 @@ class vDuration:
         except:
             raise ValueError('Invalid iCalendar duration: %s' % ical)
 
-    from_ical = staticmethod(from_ical)
-
 
 class vPeriod:
     """A precise period of time.
@@ -819,6 +823,7 @@ class vPeriod:
         return '%s/%s' % (vDatetime(self.start).to_ical(),
                           vDatetime(self.end).to_ical())
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -829,8 +834,6 @@ class vPeriod:
         except:
             raise ValueError, 'Expected period format, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
     def __repr__(self):
         if self.by_duration:
             p = (self.start, self.duration)
@@ -896,6 +899,7 @@ class vWeekday(str):
     def to_ical(self):
         return self.upper()
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -903,8 +907,6 @@ class vWeekday(str):
         except:
             raise ValueError, 'Expected weekday abbrevation, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vFrequency(str):
     """A simple class that catches illegal values.
@@ -939,6 +941,7 @@ class vFrequency(str):
     def to_ical(self):
         return self.upper()
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -946,8 +949,6 @@ class vFrequency(str):
         except:
             raise ValueError, 'Expected frequency, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vRecur(CaselessDict):
     """Recurrence definition.
@@ -1057,12 +1058,13 @@ class vRecur(CaselessDict):
             result.append('%s=%s' % (key, vals))
         return ';'.join(result)
 
+    @staticmethod
     def parse_type(key, values):
         # integers
         parser = vRecur.types.get(key, vText)
         return [parser.from_ical(v) for v in values.split(',')]
-    parse_type = staticmethod(parse_type)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -1074,8 +1076,6 @@ class vRecur(CaselessDict):
         except:
             raise ValueError, 'Error in recurrence rule: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vText(unicode):
     """Simple text.
@@ -1134,6 +1134,7 @@ class vText(unicode):
     def to_ical(self):
         return escape_char(self).encode(self.encoding)
 
+    @staticmethod
     def from_ical(ical):
         """Parses the data format from ical text format.
         """
@@ -1143,8 +1144,6 @@ class vText(unicode):
         except:
             raise ValueError, 'Expected ical text, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vTime:
     """Render and generates iCalendar time format.
@@ -1175,16 +1174,16 @@ class vTime:
     def to_ical(self):
         return self.dt.strftime("%H%M%S")
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
+        # TODO: timezone support
         try:
             timetuple = map(int, (ical[:2],ical[2:4],ical[4:6]))
             return time(*timetuple)
         except:
             raise ValueError, 'Expected time, got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vUri(str):
     """Uniform resource identifier is basically just an unquoted string.
@@ -1204,6 +1203,7 @@ class vUri(str):
     def to_ical(self):
         return str(self)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -1211,12 +1211,16 @@ class vUri(str):
         except:
             raise ValueError, 'Expected , got: %s' % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vGeo:
     """A special type that is only indirectly defined in the rfc.
 
+    Pass a list
+    >>> g = vGeo([1.2, 3.0])
+    >>> g.to_ical()
+    '1.2;3.0'
+
+    Pass a tuple
     >>> g = vGeo((1.2, 3.0))
     >>> g.to_ical()
     '1.2;3.0'
@@ -1236,7 +1240,7 @@ class vGeo:
 
     def __init__(self, geo):
         try:
-            latitude, longitude = geo
+            latitude, longitude = (geo[0], geo[1])
             latitude = float(latitude)
             longitude = float(longitude)
         except:
@@ -1249,6 +1253,7 @@ class vGeo:
     def to_ical(self):
         return '%s;%s' % (self.latitude, self.longitude)
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         try:
@@ -1257,8 +1262,6 @@ class vGeo:
         except:
             raise ValueError, "Expected 'float;float' , got: %s" % ical
 
-    from_ical = staticmethod(from_ical)
-
 
 class vUTCOffset:
     """Renders itself as a utc offset.
@@ -1339,6 +1342,7 @@ class vUTCOffset:
         duration = '%02i%02i' % (hours, minutes)
         return sign % duration
 
+    @staticmethod
     def from_ical(ical):
         "Parses the data format from ical text format"
         if isinstance(ical, vUTCOffset):
@@ -1357,8 +1361,6 @@ class vUTCOffset:
             return -offset
         return offset
 
-    from_ical = staticmethod(from_ical)
-
 
 class vInline(str):
     """This is an especially dumb class that just holds raw unparsed text and
@@ -1384,11 +1386,10 @@ class vInline(str):
     def to_ical(self):
         return str(self)
 
+    @staticmethod
     def from_ical(ical):
         return str(ical)
 
-    from_ical = staticmethod(from_ical)
-
 
 class TypesFactory(CaselessDict):
     """All Value types defined in rfc 2445 are registered in this factory
