@@ -1,8 +1,12 @@
 # -*- coding: utf-8 -*-
-import unittest2 as unittest
 import icalendar
 import os
 
+import unittest
+if not hasattr(unittest.TestCase, 'assertIsNotNone'):
+    import unittest2 as unittest
+
+
 class TestCases(unittest.TestCase):
 
     def test_case_meetup(self):
