@@ -1,8 +1,12 @@
-import unittest2 as unittest
 import icalendar
 import datetime
 import os
 
+import unittest
+if not hasattr(unittest.TestCase, 'assertIsNotNone'):
+    import unittest2 as unittest
+
+
 class TestTime(unittest.TestCase):
 
     def setUp(self):
